package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.30.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.30.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````V!4``#0````X@0````0`!30`(``'
M`"@`%@`5``8````T````-````#0```#@````X`````0````$`````P```!0!
M```4`0``%`$``!@````8````!`````$````!````````````````````G'P`
M`)Q\```%```````!``$```#`?0``P'T!`,!]`0!\`@``K!(```8```````$`
M`@```,A]``#(?0$`R'T!`/````#P````!@````0```!1Y71D````````````
M```````````````&````$````%+E=&3`?0``P'T!`,!]`0!``@``0`(```0`
M```!````+VQI8B]L9"UM=7-L+6%R;6AF+G-O+C$`$0```$\````(````"```
M``&0$``E0`2`*(`0!:"&4(2``0``"R`$C3B`$D&*!`@(3P```%````!4````
M60```%H```!A````8@```&,`````````90```&8`````````9P```&@```!K
M```````````````!KS3H:G^:?.K3[P[.WD<M;\7?'R[%F[:XC?$.U&34?'94
M/)0A_^0.V7%8'/JA;&#"Y3\LL@&+;T+ZUX?B1\8!6.^7>;OCDGQ5PSS29Z_,
M9H@'<--#1=7L,V+;[16,)<Q_J9R;X*<""FH:GE"_VE<;H^#[20``````````
M````````````````8!`````````#``<```````"``0```````P`1``P`````
M`````````!(```#:`0`````````````2````%```````````````$0`````"
M`````````````!$```!\`0`````````````2````&P``````````````$@``
M`+D!`````````````!(````C```````````````2````*@``````````````
M$@````T"`````````````!(```#%`0`````````````2````,P``````````
M````(````$X#`````````````"$```!+```````````````2````40``````
M````````$@```%@``````````````!(````;`P`````````````2````#`,`
M````````````$@```)("`````````````!(```!?```````````````2````
M,P(`````````````$@```&8``````````````!(```#'`@`````````````2
M````;0``````````````$@```'4``````````````!(```"P`@``````````
M```2````?0``````````````$@```(,``````````````!(```",````````
M```````@````!0,`````````````$@```*@``````````````!(```"M````
M```````````2````'@(`````````````$0```,X"`````````````!(```!@
M`@`````````````2````M```````````````$@```%("`````````````!(`
M``!R`P`````````````2````V0(`````````````$0```$T#````````````
M`!$```"$`@`````````````2````.@,`````````````$@```$\#````````
M`````!$```"[```````````````2````,@,`````````````$@```,0`````
M`````````!$```"*`0`````````````2````U@``````````````(@```.4`
M`````````````"````#[```````````````2````_0(`````````````$@``
M`'`"`````````````!(``````0`````````````2````!@$`````````````
M(````+L"`````````````!(````@`0`````````````2````J@$`````````
M````$@```"4!`````````````!(```"@`@`````````````2````F0$`````
M````````$@```"L!`````````````!(````\`0`````````````2````+@(`
M````````````$@```'X``````````````!(````_`@`````````````2````
M>0(`````````````$@```"L#`````````````!(```!"`0`````````````2
M````(P,`````````````$@```%8!`````````````!(````I`@``````````
M```2````Z`$`````````````$@```%T!`````````````!(```!D`0``````
M```````2````3`,`````````````(0```'4!`````````````!(```!R!```
M;)`!```````0`!(`1P,``&@3``!P`@``$@`)`/H!``!`/P``!````!(`"@"T
M`P``:"8``,P&```2``D`@@0``,0P``!8````$@`)`)$#``"L'P``!````!(`
M"0`F!```8!````0````2``<`UP,``#0M``"0`P``$@`)`"P$```\@`$`````
M`!``$@!:!```L!\``"P"```2``D`#P0``#R``0``````$``2`*(#``"T)0``
MM````!(`"0#!`P``E!T``%P````2``D`R0,``#0E``!H````$@`)`.T#``#$
M/```1`$``!(`"0`"!```W"$``!P````2``D`&P0``&R0`0``````$``2`'T$
M``!LD`$``````!``$@!7`P``_!4``&0````2``D`.@0``/@A```(`0``$@`)
M`/@#```X@`$`!````!$`$0!3!```/(`!```````0`!$`%`0``-@5````````
M$@`)`",$``!T/```4````!(`"0!@`P``G"4``!@````2``D`>P,``%P>``!0
M`0``$@`)`&<$```(/@``.`$``!(`"0!Q!```;)`!```````0`!(`1@0````C
M```T`@``$@`)``!L:6)P97)L+G-O`&]P96YD:7(`<W1D97)R`')E86QL;V,`
M86-C97-S`'-N<')I;G1F`%]?9&5R96=I<W1E<E]F<F%M95]I;F9O`&QS965K
M`&=E='!I9`!S=')C;7``;65M<V5T`'5N;&EN:P!M96UM;W9E`'-T<FYC;7``
M;'-T870`8VQO<V5D:7(`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`&]P
M96X`<W1R<W1R`'-T<F-H<@!R96%D;&EN:P!?7W-T86-K7V-H:U]G=6%R9`!?
M7V-X85]F:6YA;&EZ90!?7W)E9VES=&5R7V9R86UE7VEN9F\`97AI=`!C;&]S
M90!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`')E860`<FUD:7(`7U]E<G)N
M;U]L;V-A=&EO;@!M:V1I<@!P=&AR96%D7V=E='-P96-I9FEC`&UE;6-P>0!S
M=')L96X`7U]S=&%C:U]C:&M?9F%I;`!G971U:60`4&5R;%]S>7-?=&5R;0!0
M97)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T
M`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI
M9G0`4&5R;%]S=E\R<'9?9FQA9W,`7V9I;FD`4$Q?9&]?=6YD=6UP`%!E<FQ?
M;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`
M4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C
M:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V
M7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y
M<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8F,N;75S;"UA
M<FUH9BYS;RXQ`&9P<FEN=&8`<W1R9'5P`'!T:')E861?871F;W)K`')E861D
M:7(`<W!R:6YT9@!S=')T;VL`<W1R;F-P>0!?7VQI8F-?<W1A<G1?;6%I;@!?
M7U]E;G9I<F]N`%]S=&%R=%]C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED
M`'!A<E]C=7)R96YT7V5X96-?<')O8P!P87)?8W5R<F5N=%]E>&5C`'!A<E]S
M971U<%]L:6)P871H`'!A<E]M:W1M<&1I<@!X<U]I;FET`'!A<E]E;G9?8VQE
M86X`6%-?26YT97)N86QS7U!!4E]"3T]4`'-H85]U<&1A=&4`;7E?<&%R7W!L
M`'!A<E]B87-E;F%M90!?7V)S<U]S=&%R=`!?7V5N9%]?`'-H85]I;FET`%]?
M8G-S7W-T87)T7U\`<&%R7V1I<FYA;64`<&%R7VEN:71?96YV`%]E9&%T80!P
M87)?9FEN9'!R;V<`<VAA7V9I;F%L`%]?8G-S7V5N9%]?`%]E;F0`<&%R7V-L
M96%N=7``+W5S<B]L:6(O<&5R;#4O8V]R95]P97)L+T-/4D4`P'T!`!<```#$
M?0$`%P```+Q_`0`7````R'\!`!<```#4?P$`%P````"``0`7````"(`!`!<`
M```,@`$`%P```!2``0`7````&(`!`!<````<@`$`%P```""``0`7````)(`!
M`!<````L@`$`%P```#"``0`7````.(`!`!<```#`?P$`%04``,1_`0`5!@``
MS'\!`!4.``#0?P$`%1\``-A_`0`5(P``W'\!`!4I``#@?P$`%2T``.1_`0`5
M,```Z'\!`!4R``#L?P$`%3,``/!_`0`5.```]'\!`!4]``#X?P$`%3X``/Q_
M`0`50P``Q'X!`!8#``#(?@$`%@0``,Q^`0`6!P``T'X!`!8(``#4?@$`%@D`
M`-A^`0`6"@``W'X!`!8+``#@?@$`%@P``.1^`0`6#0``Z'X!`!8.``#L?@$`
M%A```/!^`0`6$0``]'X!`!82``#X?@$`%A,``/Q^`0`6%````'\!`!85```$
M?P$`%A8```A_`0`6%P``#'\!`!88```0?P$`%AD``!1_`0`6&@``&'\!`!8;
M```<?P$`%AP``"!_`0`6'0``)'\!`!8>```H?P$`%B```"Q_`0`6(0``,'\!
M`!8B```T?P$`%B0``#A_`0`6)0``/'\!`!8F``!`?P$`%B<``$1_`0`6*```
M2'\!`!8K``!,?P$`%BP``%!_`0`6+@``5'\!`!8O``!8?P$`%C$``%Q_`0`6
M,@``8'\!`!8S``!D?P$`%C0``&A_`0`6-0``;'\!`!8V``!P?P$`%C<``'1_
M`0`6.0``>'\!`!8Z``!\?P$`%CL``(!_`0`6/```A'\!`!8_``"(?P$`%D``
M`(Q_`0`600``D'\!`!9"``"4?P$`%D0``)A_`0`610``G'\!`!9&``"@?P$`
M%D<``*1_`0`62```J'\!`!9)``"L?P$`%DH``+!_`0`62P``M'\!`!9,``"X
M?P$`%DX```%`+>D!0+WH'O\OX03@+>4$X)_E#N"/X`CPON4\;@$``,:/XA;*
MC.(\_KSE`,:/XA;*C.(T_KSE`,:/XA;*C.(L_KSE`,:/XA;*C.(D_KSE`,:/
MXA;*C.(<_KSE`,:/XA;*C.(4_KSE`,:/XA;*C.(,_KSE`,:/XA;*C.($_KSE
M`,:/XA;*C.+\_;SE`,:/XA;*C.+T_;SE`,:/XA;*C.+L_;SE`,:/XA;*C.+D
M_;SE`,:/XA;*C.+<_;SE`,:/XA;*C.+4_;SE`,:/XA;*C.+,_;SE`,:/XA;*
MC.+$_;SE`,:/XA;*C.*\_;SE`,:/XA;*C.*T_;SE`,:/XA;*C.*L_;SE`,:/
MXA;*C.*D_;SE`,:/XA;*C.*<_;SE`,:/XA;*C.*4_;SE`,:/XA;*C.*,_;SE
M`,:/XA;*C.*$_;SE`,:/XA;*C.)\_;SE`,:/XA;*C.)T_;SE`,:/XA;*C.)L
M_;SE`,:/XA;*C.)D_;SE`,:/XA;*C.)<_;SE`,:/XA;*C.)4_;SE`,:/XA;*
MC.),_;SE`,:/XA;*C.)$_;SE`,:/XA;*C.(\_;SE`,:/XA;*C.(T_;SE`,:/
MXA;*C.(L_;SE`,:/XA;*C.(D_;SE`,:/XA;*C.(<_;SE`,:/XA;*C.(4_;SE
M`,:/XA;*C.(,_;SE`,:/XA;*C.($_;SE`,:/XA;*C.+\_+SE`,:/XA;*C.+T
M_+SE`,:/XA;*C.+L_+SE`,:/XA;*C.+D_+SE`,:/XA;*C.+<_+SE`,:/XA;*
MC.+4_+SE`,:/XA;*C.+,_+SE`,:/XA;*C.+$_+SE`,:/XA;*C.*\_+SE`,:/
MXA;*C.*T_+SE`,:/XA;*C.*L_+SE`,:/XA;*C.*D_+SE`,:/XA;*C.*<_+SE
M`,:/XA;*C.*4_+SE`,:/XA;*C.*,_+SE`,:/XA;*C.*$_+SE`,:/XA;*C.)\
M_+SE`,:/XA;*C.)T_+SE`,:/XA;*C.)L_+SE`,:/XA;*C.)D_+SE`,:/XA;*
MC.)<_+SE`,:/XA;*C.)4_+SE<$`MZ2#03>(<`(WE&!"-Y10@C>48$(WB%""-
MXAP`C>+\09_EJO__Z_@QG^4$0(_@`S"4YPPPC>7L,9_E#""=Y0,PE.<"$*#A
M`P"@X1`PC>5:___KU#&?Y0,PE.<`8-/ES#&?Y0``5N,#4)3G"P``&GS__^N\
M(9_E``!0XP(@C^`0`(+E`0``&@$`H..9___KJO__ZP``E>7`___K/6?`Y0``
ME>6]___KGC/0Y0(P@^.>,\#E``"5Y;C__^N>,]#E`3"#XYXSP.4<`)WE!0"`
MX@<!<.,&``":7#&?Y5P!G^4#,)3G``"/X`,0H.$,,(WE(/__ZP`!H.&*___K
M`!"@X1C`G>4X,9_E`""<Y0,PC^``((#E+"&?Y0@`@^4"((_@!""`Y2`AG^4"
M((_@`""2Y0@@@.44(9_E`B"/X`P@H>4$(*#C!""#Y0$PH.,<()WE`P!2X2X`
M`,H`,*#C#1&"XNQ0G^4!,8#GZ!"?Y0`PC>4%4(_@`#"@X0,@@N(0`)7E`1"/
MX"7__^L`0%#B`@``&A``E>5=___K`$"@X;A0G^4%4(_@$`"5Y3W__^NL`)_E
M``"/X-X``.L``%#C#```&@PPE>4``%/C`P``&I``G^4``(_@U@``ZPP`A>6$
M,)_E`S"/X`P`D^4``%#C````"MD&`.MP,)_E`S"/X!``D^5O___KR?[_ZP0`
MH.$@T(WB<("]Z`/AG.<!,(/B!."AY<K__^H<:P$`1`$``$`!```,`0``(`$`
M`&QL`0`D`0``92L``-QK`0!S+0``H&L!`%HM``!X:P$```D``$AK`0#K*@``
M@"H```AK`0#P:@$``+"@XP#@H.,0$)_E`1"/X`T`H.$/P,#C#-"@X0```.O<
M9P$`'T`MZ4@PG^5(()_E`S"/X`(@D^<(((WE/""?Y0(@D^<,((WE`""@XP0@
MC>4L()_E`C"3YP0@@.(`,(WE`!"0Y0@PG>4,`)WE\_[_ZQ30C>($\)WDJ&@!
M`!P!```$`0``$`$``$``G^5`,)_E0""?Y0``C^`#,(_@``!3X0(@C^`>_R\!
M+#"?Y0C03>(#,)+G!#"-Y0``4^,!```*"-"-XA/_+^$(T(WB'O\OX<AI`0#$
M:0$`.&@!`!@!``!,`)_E3!"?Y0``C^`!$(_@`#!!X*,?H.$\()_E0Q&!X,$0
ML.$"((_@'O\O`2PPG^4(T$WB`S"2YP0PC>4``%/C`0``"@C0C>(3_R_A"-"-
MXA[_+^%T:0$`<&D!`-1G`0`X`0``:#"?Y1!`+>D#,(_@`##3Y5Q`G^4``%/C
M!$"/X!"`O1A0,)_E`S"4YP``4^,"```*1#"?Y0,`G^>[_O_KP/__ZS@PG^4#
M,)3G``!3XP(```HL`)_E``"/X%S^_^L!(*#C(#"?Y0,PC^``(,/E$("]Z!!I
M`0!\9P$`,`$``*AH`0`4`0``(&4``+1H`0`P,)_E,""?Y0,PC^`",)/G``!3
MXP8```H00"WI'!"?Y1P`G^4!$(_@``"/X)[^_^L00+WHM?__Z@!G`0`T`0``
M;&@!`,!D``"<,)_E\$<MZ0!04.(#,(_@!4"@`2````J(()_E`C"3YP!`D^4`
M`%3C&P``"@&0H.$%,*#A`V"@X0$0T^0``%'C/0!1$_K__QH$@*#A!6!&X`AP
MH.$$H)CD``!:XPI`H`$-```*!B"@X040H.$*`*#A1?[_ZP``4./T__\:!C#:
MYST`4^/Q__\:!$!'X$1!H.$`0(GE`4"&X@1`BN`$`*#A\(>]Z+1F`0`H`0``
M!T`MZ4@@G^5(,)_E`B"/X`,PDN<-$*#A`#"3Y00PC>4`,*#CRO__ZRP@G^4D
M,)_E`B"/X`,PDN<`()/E!#"=Y0(@,^`````*F?[_ZPS0C>($\)WD"&8!`"P!
M``#D90$`<T`MZ8P@G^6,,)_E`B"/X`,PDN<`0*#A`#"3Y00PC>4`,*#C#6"@
MX7!0G^4%4(_@!A"@X00`H.&M___K``!0XP@``!I8()_E3#"?Y0(@C^`#,)+G
M`""3Y00PG>4"(#/@"@``"GK^_^LX,)_E`""=Y0,PE><`,)/E`C&#X`0@D^4`
M`%+C!""#Y/O__QKG___J"-"-XG"`O>BH90$`+`$``(AE`0!H90$`*`$``/!/
M+>D!4*#AR"&?Y<@QG^4"((_@`S"2YQ303>(`,)/E##"-Y0`PH.,`,-'E`&"@
MX3T`4^,!4($"!0"@X5;^_^L($(WB`'"@X08`H.%]___KB)&?Y0!`4.()D(_@
M$0``"DW^_^L'`%#A-@``.@%`1.(!,-7D``!3XP$PY.7[__\:``"@XU@AG^5,
M,9_E`B"/X`,PDN<`()/E##"=Y0(@,^!*```*/_[_ZS@QG^4#H)GG`+":Y00Q
MF^<``%/C#@``&B0QG^4"@(3B`S"/X``@D^4(@:#A``!2XPD```H($*#A"P"@
MX83]_^L``%#C``"*Y0\``!H``.#CX?__Z@%`A.+K___J`2"@XP@`H.$`((/E
MJ?W_ZP`P4.($,(WE]/__"@L0H.$(($CBIOW_ZP0PG>4`,(KE`#":Y0B`@^``
M,*#C!#`(Y0A`C>4&,*#A`P"@X0$@T^0``%+C/0!2$_K__QJ`,)_E!@!`X`-`
MF><"<(?B!P"`X`B0G>4`@)3ECOW_ZP``4.,)`8CGV?__"@`PE.4(()WE`B&3
MYP$0UN0",*#A/0!1XP``41,`$,+E`2""XOC__QH](*#C`"##Y0$@U>0``%+C
M`2#CY?O__QJK___J%-"-XO"/O>CX9`$`+`$``+!D`0!\9`$`*`$``.!E`0#P
M1RWI/"&?Y3PQG^4"((_@`S"2YW#03>(`4%#B`#"3Y6PPC>4`,*#C$P``"@`P
MU>4``%/C$```"BK]_^L`8%#B#0``"@1QG^4$@9_E!)&?Y0=PC^`(@(_@"9"/
MX`8`H.%'_?_K`$!0X@P``!H&`*#A9/W_ZP4`H.&G_?_KV""?Y<0PG^4"((_@
M`S"2YP`@D^5L,)WE`B`SX"@```K%_?_K$T"$X@<0H.$$`*#A,?W_ZP``4./H
M__\*"!"@X00`H.$L_?_K``!0X^/__PH%`*#AM?W_ZP"@H.$$`*#ALOW_ZP``
MBN`"`(#B-_W_ZP"@H.$$,*#A!2"@X0D0H.&>_?_K#1"@X0H`H.&/_?_K`0!P
MXPH`H.$'```*$#"=Y0\Z`^(!"5/C`P``&K3__^L*`*#A@OW_Z\C__^H@_?_K
M^O__ZG#0C>+PA[WH#&,!`"P!``"'(P``@B,``($C``"48@$`$$`MZ80@G^6$
M,)_E`B"/X'#03>(#,)+G#1"@X0!`H.$`,)/E;#"-Y0`PH.,:_?_K``!0XP``
MH!,)```:$#"=Y0\Z`^(*"E/C`0E3$P0``!H"$*#C!`"@X=G\_^L0#V_AH`*@
MX2P@G^4D,)_E`B"/X`,PDN<`()/E;#"=Y0(@,^`````*<_W_ZW#0C>(0@+WH
MK&$!`"P!``!,80$`$T`MZ3Q`G^4\,)_E!$"/X`,PE.<``)/E5?W_ZRPPG^4L
M$)_E`S"4YP$0C^`$,(WE(#"?Y00@G>4#,(_@"-"-XA!`O>A$_?_J$&$!`"`!
M```\`0``NR$``)9>```30"WI3#"?Y4P@G^4#,(_@`D"3YP``E.4^_?_KX/__
MZP``E.4[_?_K`""@XRPPG^4$((WE*!"?Y2@@G^4#,(_@`#"-Y0(@C^`!$(_@
MI/S_ZPC0C>(0@+WHM&`!`"`!``#*(P``6R$``/@.``#P0"WI+!&?Y2PAG^4"
MVDWB'-!-X@$0C^`"()'G`CJ-XA0P@^(`()+E`""#Y0`@H..<_/_K!"&?Y01A
MG^4"((_@`""-Y?P@G^4,<(WB`#"@X080H.$'`*#A`B"/X(+\_^L!,(#B!@!3
MX0```)KP`/#G`0!PXPL``!H`,*#CR`"?Y;00G^4``(_@`BJ-X@$0D.<4((+B
M``"1Y0`0DN4``#'@(```"A+]_^L!6HWB$%"%X@$JH.,%$*#A!P"@X<'\_^L`
M0%#BZ___N@$`A.*-_/_K`#!0XN?__PH%`%/A`@``*@0@@^`"`%7AW___.@4`
M4^$"``":!""%X`(`4^':__\Z!@!4X=C__\H$(*#A`P"@X040H.'J_/_K`""@
MXP`PH.$$(,#GU/__Z@,`H.$"VHWB'-"-XO"`O>A`8`$`+`$``!PA```!$```
M]"```-!?`0"J___J\$\MZ0%0H.'L$9_E["&?Y4+=3>(!$(_@!-!-X@!`H.'<
M`9_E`B"1YT$]C>(``(_@/#"#X@`@DN4`((/E`""@XRG^_^LO$*#C`&"@X00`
MH.%X_/_K``!0XPX```JD`9_E!!"@X0``C^!B_O_KF!&?Y8@AG^4!$(_@03V-
MX@(@D><\,(/B`!"2Y0`@D^4!$#+@50``"L'\_^L$`*#AO/S_ZV@1G^4,`(WE
M`1"/X`4`H.&E_/_K`'"@X521G^54H9_E5+&?Y0F0C^`*H(_@"["/X```5^/@
M__\*`"#7Y0``4N,)<*`!``!6XPD```H'$*#A!@"@X1G\_^L``%#C!```&A@1
MG^4!$(_@C_S_ZP!PH.'N___J!P"@X9W\_^L`P*#C``"'X`<00.`!('#E+P!2
MXQ$```H,,)WE`2"#X@$@@N`!"E+CQ/__JH"`C>($4$CB!S"@X0H@H.$!&J#C
M!0"@X01`C>4`L(WEZOO_ZP$`@.(!"E#C`@``FO``\.<`P,#EY___Z@4`H.$0
M$(WB:/S_ZP``4.,0```:8#`8Y0\Z`^(""5/C#```&@$0H.,%`*#AU?O_ZP``
M4.,'```:8`"?Y040H.$``(_@"O[_ZP4`H.$)_/_K`$"@X:/__^I$$)_E``"@
MXP$0C^#&___J!`"@X4+=C>($T(WB\(^]Z.Q>`0`L`0``W!\``*T?``",7@$`
M=A\``/L>```D(```5!\``!H?``!-'@``.AX````PH.$!(-/D``!2XQ[_+P$O
M`%+C`P"@`?G__^H00"WI`$!0X@(```H`,-3E``!3XP,``!K8`)_E``"/X!!`
MO>CB^__J1_S_ZP$`0.(``(3@``!4X0`PH.$;```J`"#3Y0$`0.(O`%+C^/__
M"@`0T^4#(*#A+P!1XP$P0^(0```:`C"@X0$P0^(#`%3A`R"@X0,``"H`$-+E
M`3!#XB\`4>/X__\*!"!"X`(P@N(!"E/C%0``B@$@@N(!"E+C#```FO``\.<#
M`%3AY___.@,`5.'K__\:`##4Y2\`4^,T`)\%``"/`-3__PHL`)_E``"/X-'_
M_^HD,)_E!!"@X0,PC^`#`*#ATOO_ZQ"`O>@``*#C$("]Z%L=``"S'```"!T`
M`(Q=`0`00"WIP"&?Y<`QG^4"((_@*-!-X@,PDN<-(*#AL!&?Y0`PD^4D,(WE
M`#"@XP$0C^`*,('B*L"!X@+@H.$``)/E!!"3Y0@P@^(#`*[H#`!3X0X@H.'W
M__\:L##3X70!G^6P,,[A``"/X&/]_^MH`9_E:$&?Y0``C^!?_?_K8`&?Y01`
MC^```(_@6_W_ZU0!G^4``(_@6/W_ZTP!G^4``(_@5?W_ZT0!G^4``(_@4OW_
MZSP!G^4``(_@3_W_ZS0!G^4``(_@3/W_ZP0`H.%*_?_K)`&?Y0``C^!'_?_K
M'`&?Y0``C^!$_?_K%`&?Y0``C^`I_?_K`!!0X@$```H$`*#A:/W_Z_P`G^4`
M`(_@(OW_ZP`04.("```*[`"?Y0``C^!@_?_KY`"?Y0``C^`:_?_K`!!0XA``
M``K4`)_E``"/X%C]_^O,$)_ES`"?Y0$0C^```(_@4_W_Z\`@G^5L,)_E`B"/
MX`,PDN<`()/E)#"=Y0(@,^`2```*M/O_ZZ``G^4``(_@!/W_ZP`04.*4`)\5
M``"/$.G__QJ,$)_E"B"@XP$0C^`1`(WB,_O_ZP``4./C__\:=`"?Y1L0C>(`
M`(_@WO__ZBC0C>(0@+WHI%L!`"P!```V60``;AP``&<<``"9'```7QP``%P<
M``!7'```6QP```0<``!/'```3QP``.$;``!!'```-AP``"T;```H'```?!L`
M`#`<``"C&P``4%H!`.`;``!_&P``T1L``%,;```00"WI3#"?Y0,PC^``,)/E
M`0!SXPP``!H\`)_E``"/X-#\_^L``%#C!```"@``T.4P`%#C``!0$P$`H!,`
M`*`#&#"?Y0,PC^```(/E$#"?Y0,`G^<0@+WHP%H!`+\:``"$6@$`>%H!`!!`
M+>EM^__K%?O_ZP``4.,``)`5$("]Z/=`+>F8<)_E`$"@X0=PC^`'`*#AL_S_
MZP!04.($$*#A`@``"@`PU>4``%/C!```&G``G^4``(_@#-"-XO!`O>CK_/_J
M\?K_ZP``4.,2```:!`"@X4W[_^L`8*#A!0"@X4K[_^L``(;@`@"`XL_Z_^L`
M8*#A,#"?Y3`0G^4$(*#A`1"/X`!0C>4#,(_@,_O_ZP80H.$'`*#AYO__Z@S0
MC>+P@+WHOAH``)8:``"2&0``:!H``/!/+>D\%I_E/":?Y0+93>+TT$WB`1"/
MX##&G^4"()'G`CF-XO!`C>(,P(_@`""2Y>P@@^4`(*#C[#"#XA!0C.)T,$3B
M7.!$X@!@H.$'`)SI!P"#Z`\`M>@/`*[H`P"5Z&@P1.(HP(SB`P".Z`<`G.@'
M`(/HV`6?Y=AUG^4``(_@:_S_ZP!04.('<(_@$0``"@`PU>4``%/C#@``"JK_
M_^L%`*#AIOK_ZP!0H.&H%9_EE"6?Y0$0C^`".8WB`B"1Y^PP@^(`$)+E`""3
MY0$0,N!8`0`*`_O_ZY7__^L`4%#B:(!$`E@```H%`*#A^OK_ZX``H.$!`(#B
M?_K_ZP"0H.$`@*#A5*6?Y0%01>(*H(_@`2#UY0``4N-1```:7(!$X@10F.0`
M`%7C#```"@4`H.$__/_K`%!0XOC__PH`,-7E``!3X_7__PI0_?_K``!0X_+_
M_PH%`*#A>?K_ZP!0H.%TH$3B``!5XP4``!H$@)KD``!8XT<```H`,-CE``!3
MXSP``!H%`*#AT_K_ZP"@H.$)`*#AT/K_ZP``BN`!JX#B!*"*X@H`H.%3^O_K
M`("@X:PTG^6L%)_E`S"/X``PC>6D-)_E!2"@X0,PC^`!$(_@!)"-Y;3Z_^L'
M':#C"`"@X9_Z_^L!`'#C+```&IGZ_^L`,)#E$0!3XR@```IL))_E;!2?Y0(`
ME^<`,(WE`""6Y0@PH.$``)#E`1"/X'CZ_^L`4*#CH/__Z@'\_^L`,%#B!0``
M"@`PT^4``%/C`@``"C_Z_^L`4%#BIO__&@0`F.0``%#C\___&AA4G^4%4(_@
MH/__Z@@`H.$*$*#ACOK_ZP*`B.*E___J"`"@X0/]_^L``%#CN/__"@@`H.$L
M^O_K`%"@X;+__^H(4*#AN/__Z@@`H.'@$$3B'_K_ZP"04.((```*M#.?Y;P3
MG^4#`)?G`""6Y0@PH.$!$(_@``"0Y4OZ_^O1___JT#`4Y0\Z`^(!"5/C\O__
M&LA0%.6`^O_K``!5X>[__QK0,!3E@SN@X:,[H.$'#5/CZ?__&@H`H.'Y^?_K
M`%"@X6`#G^4``(_@P_O_ZP``4.-A```:`'"6Y0<`H.%H^O_K`P!0XP"@H.$:
M``":.!.?Y00`0.(!$(_@``"'X-/Y_^L``%#C$P``&@0`6N,#```*"J"'X`4P
M6N4O`%/C#0``&@1@EN4``%;C"@``"@8`H.%3^O_K`P!0XP8``)KL$I_E!`!`
MX@$0C^```(;@O_G_ZP``4.,&<*`!Q?[_ZP"@4.)U```:"A"@X0<`H.'A^?_K
M`&!0XG````H"D*#C`##@XQ$@X.,`D(WE!'!$XJGY_^L&(*#C!Q"@X08`H.$.
M^O_K!#!4Y0``4^,S```:`S!4Y4,`4^,P```:`C!4Y4$`4^,M```:`3!4Y4,`
M4^,J```:`##4Y4@`4^,G```:`3#4Y44`4^,D```:`##@XSD@X.,&`*#A`)"-
MY8[Y_^LI(*#C!Q"@X08`H.'S^?_K"""@X1PRG^4<$I_E`S"/X`0PC>44,I_E
M`'"-Y0,PC^`!$(_@!0"@X0;Z_^L(`*#A]?G_Z_@!G^4%$*#A``"/X*7[_^L%
M`*#AIO[_Z_W^_^H`<);EH?G_ZP`0H.$'`*#A'_W_ZP!P4.*7__\:E?__Z@`P
MH.,`(*#C`#"-Y08`H.$`,*#C:/G_ZT8$`.L`D*#A`BF@XP<0H.$&`*#AR_G_
MZP`@4.(=``#*!@"@X41@1.+`^?_K,'!$X@D0H.$&`*#AG00`ZP>0H.%HL9_E
M"["/X`<`H.$+$*#A`2#6Y`&@BN+8^?_K%`!:XP)PA^+W__\:`#"@XP@P1.4\
M,9_E/!&?Y0,PC^`$,(WE-#&?Y0@@H.$`D(WE`S"/X`$0C^#`___J!Q"@X0D`
MH.$R!`#KU___ZA`1G^40`9_E`1"/X```C^!E^__K._G_ZP`QG^4`$9_E`S"/
MX`D`C>CX,)_E"""@X04`H.$#,(_@`1"/X+7Y_^OD0)_EY&"?Y>1PG^4$0(_@
M!F"/X`=PC^`'':#C!0"@X9KY_^L!`'#CH___&I3Y_^L`,)#E$0!3XY___QHA
M^?_K`9")X@$"C>@$,*#A"""@X080H.$%`*#A"'"-Y9WY_^OL___J!0"@X0+9
MC>+TT(WB\(^]Z#18`0`L`0``;%D!`-08``#`5P$`E%<!`"$9``"#&```9A@`
M`*`7```(`0``*!@``,H7``"S%P``!1<``((7```W%P``'A<``%06``#H%```
ML!0``/T4```J%@``7!4``/`3``!X%```!Q0``-H5```;%0``H!,``(@3```1
M%0``IA4``/=/+>DX,Y_E.".?Y0,PC^`"0)/G``"4Y6WY_^L`4*#A``"4Y6KY
M_^MD,-7E93#`Y10#G^4``(_@ROK_ZP``4.,%```*`##0Y3$`4^,"```:`3#0
MY0``4^,````*6OW_ZP``E.5:^?_KX!*?Y0LPH.,!(*#C`1"/X`KY_^L``%#C
M'@``&@``E.51^?_KP!*?Y0,PH.,!(*#C`1"/X`'Y_^L`4%#B3@``&@``E.5(
M^?_KH!*?Y0,PH.,!(*#C`1"/X/CX_^L`4%#B8@``"H@"G^4``(_@H_K_ZP`@
M4.($((WE40``"@``E.4Y^?_K##"5Y00@G>4`$)/E\/C_ZU4``.H!4*#C##"0
MY5"2G^48<)/E3**?Y0F0C^`$,)GE``"4Y04`4^$!@$7B!@``VBCY_^L`,*#C
M"""@X0<0H.&O^/_K`&!0X@@``!H8,I_E`S"/X`0@D^4!($+B`@!8X<C__QH!
M8*#C`U"@X1@``.H(,)GE`""6Y06QD^<(,)+E"C`#X`$+4^,,$)(%!@``"@``
ME.4/^?_K`!"6Y0(PH.,`(*#C%_G_ZP`0H.$+`*#ABOC_ZP``4./C__\:`5"%
MXM7__^H#^?_K!Q"@X6+X_^L!8(;B!#"5Y0``E.4&`%/A]___RJ?__^H``)3E
M^?C_ZPPPE>5T(9_E`!"3Y0(@C^"O^/_K##"5Y0`PD^4(,)/E`043XZ3__PH`
M`)3E[?C_ZPPPE>4`$)/E>_C_ZY[__^J]^__K`&!0X@``E.4H```*Y/C_ZPPP
ME>4&(*#A`!"3Y9OX_^L&`*#ATOC_ZP``E.7<^/_K`%"@X0``E.79^/_K_!"?
MY0$@H.,!$(_@/_C_Z_`@G^4`$*#A`B"/X`4`H.&+^/_K``"4Y<[X_^L`,*#C
M93#`Y=``G^700)_E``"/X"WZ_^L$0(_@``!0XPP`A.4.```:"`"4Y9K]_^L`
M`%#C#`"$Y0D``!JD`)_E``"/X#+X_^N[^/_KF#"?Y0,PC^`(()/E##"5Y0`@
MDN5]___JA$"?Y0<=H.,$0(_@#`"4Y:'X_^L!,(#B$0!0XP$`4Q,&``":`#"@
MX0@0E.5<`)_E#""4Y0`0D>4``(_@&_C_ZPS0C>+PC[WH<%$!`"`!``"+$@``
MQA,``*<3``"C$P``O1$```A2`0``!"``T%$!`$D2``#2$0``UQ$``-P/``!L
M4`$`B1$``#10`0`84`$`3A$``'!`+>D`0*#A2?S_ZT'\_^L`4*#A%?W_ZP``
M4.,``%03<("]"``PU.4``%/C<("]"!P0G^4%`*#A`1"/X"_X_^L``%7A<("]
M&`0`H.%P0+WHG_K_ZJ</``#P3RWI,"N?Y3`[G^4"((_@4]]-X@,PDN<$((WB
M`L"@X0`PD^5$,8WE`#"@XUS@@.(<,(#B!!"3Y#$?O^8#`%[A!!",Y/K__QI`
MP*#C`A"@X2#@D>4T,)'E!"""X@XP(^`(X)'E`!"1Y0XP(^`!,"/@XS^@X0'`
M7.(\,(+E\O__&KPJG^4$D)WE`("0Y0@PG>740,#AW&#`X601)>`&P"7@`I")
MX`>0B>`$P`S@"!`!X`(P@^`&P"S@!C"#X.B=B>`%$"'@#)")X`,0@>!HP:#A
M##"=Y62A+.`)H`K@`C"#X`4P@^`0X)WE9*$JX.D=@>`#H(K@:3$LX`$P`^`"
MX([@X:V*X&3ACN!A$:#A%+"=Y0PP(^`.,(/@:>$AX`*PB^`*X`[@#,"+X&GA
M+N`8L)WEZCV#X`S@CN!JP2'@`K"+X`/`#.#C[8[@:9&+X&,QH.$<L)WE`<`L
MX`G`C.!JD2/@`K"+X`Z0">`!$(O@:I$IX""PG>7NS8S@`9")X&X1(^`"L(O@
M#!`!X.R=B>!JH8O@;,&@X22PG>4#$"'@"A"!X&ZA+.`"L(O@":`*X`,PB^!N
MH2K@*+"=Y>D=@>`#H(K@:3$LX`*PB^`!,`/@X:V*X&[AB^!A$:#A++"=Y0PP
M(^`.,(/@:>$AX`*PB^`*X`[@#,"+X&GA+N`PL)WEZCV#X`S@CN!JP2'@`K"+
MX`/`#.!ID8O@`<`LX./MCN`)P(S@8S&@X320G>5JL2/@`I")X`ZP"^`!$(G@
M:K$KX#B0G>7NS8S@`;"+X&X1(^`"D(G@#!`!X.R]B^!JH8G@;,&@X3R0G>4#
M$"'@"A"!X&ZA+.`"D(G@"Z`*X`,PB>!NH2K@0)"=Y>L=@>`#H(K@:S$LX`*0
MB>`!,`/@X:V*X&[AB>!A$:#A1)"=Y0PP(^`.,(/@:^$AX`*0B>`*X`[@:^$N
MX`S`B>`,P([@2."=Y>H]@^!JD2'@`N".X`.0">!KL8[@`9`IX./-C.`+D(G@
M8S&@X4RPG>5JX2/@`K"+X`S@#N!JX2[@`1"+X%"PG>7LG8G@`1".X&SA(^`"
M((O@">`.X&JA@N`#X"[@&"B?Y0K@CN!4H)WEZ1V!X`*@BN!ID:#A`S"*X&RA
M*>`!H"K@"J"#X%@PG>7A[8[@`C"#X&S!@^!A,2G@#C`CX`/`C.!<,)WE[JV*
MX`(P@^!NX:#A"9"#X&$Q+N`*,"/@`Y")X&`PG>7JS8S@`C"#X&$Q@^!J$2[@
M#!`AX`$P@^!D$)WE[)V)X`(0@>!LP:#A#N"!X&H1+.`)$"'@`>".X&@0G>5L
ML)WE`A"!X.D]@^!J$8'@::$LX./MCN`#H"K@`K"+X&,QH.$,P(O@:;$CX`ZP
M*^`+L(S@<,"=Y0H0@>`"P(S@[AV!X&G!C.!ND2/@`9`IX`G`C.!TD)WEX;V+
MX`*0B>!A$:#A`S")X&Z1(>`+D"G@"9"#X'@PG>5\H)WE`C"#X.O-C.!N,8/@
M:^$AX.R=B>`,X"[@`J"*X&S!H.$!$(K@:Z$LX`F@*N`*H('@@!"=Y0XP@^`"
M$('@A."=Y>D]@^!K$8'@:;$LX..MBN`#L"O@`N".X&,QH.$,P([@:>$CX`K@
M+N`.X(S@B,"=Y0L0@>`"P(S@C+"=Y>H=@>!IP8S@:I$CX.'MCN`!D"G@`K"+
MX&$1H.$#,(O@:K$AX`ZP*^`+L(/@D#"=Y0G`C.`",(/@[LV,X&HQ@^!NH2'@
M#*`JX`HP@^"4H)WE[+V+X`*@BN!LP:#A`1"*X&ZA+.`+H"K@"J"!X)@0G>6<
MD)WE`A"!X.L]@^!N$8'@:^$LX..MBN`#X"[@`I")X&,QH.$,D(G@:\$CX`K`
M+.`,D(G@H,"=Y0X0@>`"P(S@ZAV!X&O!C.!JL2/@X9V)X`&P*^!A$:#A:N&!
MX6HA`>`)X`[@"\",X`+@CN&DL)WEH"6?Y>G-C.`"L(O@`S"+X`/@CN!I,8'A
M:;$!X`PP`^`+,(/AJ+"=Y>SMCN`"L(O@;,&@X6JAB^!IL8SA"C"#X`ZP"^!I
MH0S@"K"+X:R@G>7N/8/@`J"*X`$0BN`!L(O@;A&,X6ZA#.`#$`'@"A"!X;"@
MG>7CO8O@`J"*X&,QH.%ID8K@"1"!X&Z1@^%NH0/@"Y`)X`J0B>&TH)WEZQV!
MX`*@BN`,P(K@#)")X&O!@^%KH0/@`<`,X`K`C.&XH)WEX9V)X`*@BN!A$:#A
M;N&*X&NA@>$.P(S@":`*X&OA`>`.H(KAO."=Y>G-C.`"X([@`S".X`.@BN!I
M,8'A:>$!X`PP`^`.,(/AP."=Y>RMBN`"X([@;,&@X6NQCN`+,(/@:;&,X6GA
M#.`*L`O@#K"+X<3@G>7J/8/@`N".X`$0CN`!L(O@:A&,X6KA#.`#$`'@#A"!
MX<C@G>7CO8O@`N".X&,QH.%ID8[@"1"!X&J1@^%JX0/@"Y`)X`Z0B>',X)WE
MZQV!X`+@CN`,P([@:^&#X0R0B>`!X`[@:\$#X`S@CN'0P)WEX9V)X`+`C.!A
M$:#A:J&,X&O!@>$*X([@"<`,X&NA`>`*P(SAU*"=Y>GMCN`"H(K@`S"*X`,P
MC.!IP8'A::$!X`[`#.`*P(SAV*"=Y>X]@^`"H(K@;N&@X6NQBN`+P(S@:;&.
MX6FA#N`#L`O@"K"+X=R@G>7CS8S@`J"*X`$0BN`!L(O@8Q&.X6.A#N`,$`'@
M"A"!X>"@G>7LO8O@`J"*X&S!H.%ID8K@"1"!X&.1C.%CH0S@"Y`)X`J0B>'D
MH)WEZQV!X`*@BN`.X(K@:Z&,X0[@B>`!H`K@:Y$,X`F@BN'HD)WEX>V.X`*0
MB>!A$:#A8S&)X`.@BN!K,8'A:Y$!X`XP`^`),(/A[)"=Y>ZMBN`"D(G@#,")
MX&Z1@>$,P(/@"I`)X&XQ`>`#D(GA\#"=Y>K-C.`"((/@:[&"X,0RG^7T()WE
M:J&@X0,@@N`!$(+@;B$JX`P@(N`"$('@^""=Y0N0B>`#((+@[)V)X&[A@N!L
M(2K@"2`BX`+@CN#\()WEZ1V!X`,@@N!ID:#A"J""X&PA*>`!("+@`J"*X``A
MG>7A[8[@`R""X&PA@N!AP2G@#L`LX`P@@N`$P9WE[JV*X`/`C.!NX:#A"9",
MX&'!+N`*P"S@#)")X`C!G>7J+8+@`\",X&'!C.!J$2[@`A`AX`'`C.`,$9WE
MXIV)X`,0@>!B(:#A#N"!X&H1(N`)$"'@`>".X!`1G>44L9WE`Q"!X.G-C.!J
M$8'@::$BX.SMCN`,H"K@`["+X&S!H.$"((O@:;$LX`ZP*^`+L(+@&"&=Y0H0
M@>`#((+@[AV!X&DA@N!ND2S@`9`IX`D@@N`<D9WEX;V+X`.0B>!A$:#A#,")
MX&Z1(>`+D"G@"9",X"#!G>4DH9WE`\",X.LM@N!NP8S@:^$AX.*=B>`"X"[@
M`Z"*X&(AH.$!$(K@:Z$BX`F@*N`*H('@*!&=Y0[`C.`#$('@+.&=Y>G-C.!K
M$8'@:;$BX.RMBN`#X([@#+`KX&S!H.$"(([@:>$LX`K@+N`.X(+@,"&=Y0L0
M@>`#((+@ZAV!X&DA@N!JD2S@`9`IX`D@@N`TD9WEX>V.X`.0B>!A$:#A#,")
MX&J1(>`.D"G@"<",X#B1G>7N+8+@`Y")X&JAB>!ND2'@`I`IX`F@BN`\D9WE
MXLV,X`.0B>!B(:#A`1")X&Z1(N`,D"G@"1"!X$"1G>7LK8K@`S")X`B`@^!N
MX8C@;($BX`J`*.#J'8'@`G"'X`C@CN!@()_E2#"?Y>'MCN`!0(3@:E&%X&QA
MAN`"((_@`."`Y01`@.4(4(#E#&"`Y1!P@.4#,)+G`""3Y40QG>4"(#/@````
M"K_U_^M3WXWB\(^]Z(A-`0`L`0``F7F"6J'KV6[<O!N/UL%BRI!"`0`00"WI
M8`"@XSCU_^LH$)_E*""?Y2C`G^4HX)_E!E"`Z"0@G^40((#E`""@XQ0@@.48
M((#E7""`Y1"`O>@!(T5GB:O-[_[<NIAV5#(0\.'2P_!!+>D"8*#A`%"@X10P
MD.6"(:#A`C"3X!@@D"44,(#E`2""(A@@@"48,)#E''"%XJ8^@^`8,(#E7`"0
MY0``4.,9```*0$!@X@0`5N$``(?@!D"@L0$`4.$#```J!#"`X`,`4>$````J
M\`#PYP$`4.$$@('@`0``F@@`4.'Y__\Z!""@X73U_^M<,)7E`S"$X$``4^-<
M,(7E\(&]&`4`H.'L_/_K"!"@X01@1N!<@(7B/P!6XPX``,H'`%'A`@``F@8P
MA^`#`%'AYO__.@<`4>$"```J!C"!X`,`5^'A__\Z!B"@X0<`H.%;]?_K7&"%
MY?"!O>@'`%'A`0``F@@`4>'8__\Z!P!1X4`P@>(!```J`P!7X=/__SH!0*#A
M!R"@X000E.0#`%3A!!""Y/O__QH%`*#AQ_S_ZT!@1N($$*#AVO__ZO!!+>D<
M@('B%#"1Y1A@D>4!0*#A?Q#@XS-_O^:C,:#A/S`#X@$@@^(X`%+C`%"@X0,0
MR.<"`(C@`!"@TS9OO^8X(&+2!P``V@`0H.-`(&+BN/3_ZP0`H.&M_/_K.""@
MXP`0H.,(`*#ALO3_ZP0`H.'T9<3AIOS_ZP,PU.4$`*#A`##%Y;(PU.$!,,7E
M`#"4Y2,TH.$",,7E`#"4Y0,PQ>4',-3E!##%Y;8PU.$%,,7E!#"4Y2,TH.$&
M,,7E!#"4Y0<PQ>4+,-3E"##%Y;HPU.$),,7E"#"4Y2,TH.$*,,7E"#"4Y0LP
MQ>4/,-3E###%Y;XPU.$-,,7E##"4Y2,TH.$.,,7E##"4Y0\PQ>43,-3E$##%
MY;(QU.$1,,7E$#"4Y2,TH.$2,,7E$#"4Y1,PQ>7P0;WHY?3_Z@%`+>D!0+WH
M'O\OX2]T;7``4$%27U1-4$1)4@!414U01$E2`%1-4`!54T52`%5315).04U%
M`"XN`"5S+R5S`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA
M;',Z.E!!4CHZ0D]/5``O<')O8R\E:2\E<P!E>&4`4$%27U1%35``4$%27U!2
M3T=.04U%`#H`+P!015),-4Q)0@!015),3$E"`%!%4DPU3U!4`%!%4DQ)3P!0
M05)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.`%!!4E]$14)5
M1P!005)?0T%#2$4`4$%27T=,3T)!3%]$14)51P!005)?1TQ/0D%,7U1-4$1)
M4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]
M`#$`3$1?3$E"4D%265]0051(`%-94U1%30`E,#)X`"5S)7,E<R5S`'!A<BT`
M)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE
M9"`H97)R;F\])6DI"@`E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@
M=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A
M=&EO;BD*`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E<R5S=&5M<"TE=25S
M`"5S)7-T96UP+25U+25U)7,`05)'5@`8`'!E<FP`4$%2.CI086-K97(Z.E9%
M4E-)3TX`,2XP-3``56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`
M)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S
M(&9A:6QE9"`H97)R;F\])6DI"@`M90`M+0!E=F%L("=E>&5C("]U<W(O8FEN
M+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U
M;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!
M1TE#+"`D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I
M9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q
M=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D
M=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*
M;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE
M.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI
M;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A
M<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&
M:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL
M93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M
M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ
M.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G
M"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E
M<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N
M86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M
M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L
M;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG
M<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF
M:6QE;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H
M*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*)%!!4E]-04=)
M0R`](")<;E!!4BYP;5QN(CL*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@
M)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T
M:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E
M>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@
M/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I
M;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E
M=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL
M;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@
M)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@
M)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q
M,#(T.PIM>2`D;6%G:6-?<&]S.PII9B`H)'-I>F4@/#T@)&-H=6YK7W-I>F4I
M('L*)&UA9VEC7W!O<R`](#`["GT@96QS:68@*"AM>2`D;2`]("1S:7IE("4@
M)&-H=6YK7W-I>F4I(#X@,"D@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D;3L*
M?2!E;'-E('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&-H=6YK7W-I>F4["GT*
M=VAI;&4@*"1M86=I8U]P;W,@/CT@,"D@>PIS965K*%]&2"P@)&UA9VEC7W!O
M<RP@,"D["G)E860H7T9(+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D
M4$%27TU!1TE#*2D["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-
M04=)0RDI(#X](#`I('L*)&UA9VEC7W!O<R`K/2`D:3L*;&%S=#L*?0HD;6%G
M:6-?<&]S("T]("1C:'5N:U]S:7IE.PI]"FQA<W0@:68@)&UA9VEC7W!O<R`\
M(#`["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"P@,#L*<F5A9"!?1D@L("1B
M=68L(#0["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"`M('5N<&%C:R@B3B(L
M("1B=68I+"`P.PHD9&%T85]P;W,@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?
M;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@
M(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@
M=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H
M<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@)&-R8R`]
M("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U
M;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ
M+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L
M("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A
M;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N
M86UE(#T@7W1E;7!F:6QE*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2
M.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*
M?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN
M960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL
M92@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@
M)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA
M;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2![
M"F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L
M"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@
M>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO
M9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2!D96QE=&4@)')E<75I<F5?
M;&ES='LD;6]D=6QE?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO
M861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@
M9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIP<FEN="`D
M9F@@)&EN9F\M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R;B`D9F@[
M"GT*96QS92!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&EN9F\M/GMC
M<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*;W!E;B!M>2`D9F@L("<\)RP@)&9I
M;&5N86UE(&]R(&1I92`B8V%N)W0@<F5A9"`D9FEL96YA;64Z("0A(CL*8FEN
M;6]D92@D9F@I.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F
M86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PI]+"!`24Y#*3L*<F5Q
M=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A
M<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL
M92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP
M72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@
M+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E
M<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S
M("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T
M92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U
M9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@
M-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R
M9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*
M9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%
M(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S
M("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP
M72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M
M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U
M;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII
M9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`
M05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L
M<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*
M=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S
M5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D
M7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@
M)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L
M("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF
M("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@
M97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G
M*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L
M;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@
M)"$B.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*
M?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@
M>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER
M92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!
M4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET
M.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T
M*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`[
M"G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6
M*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@
M)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I
M;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R
M8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D
M9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B
M4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H
M)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG
M*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N
M*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL
M;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G
M/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE
M("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+
M7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ
M1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I
M;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI
M(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD969I;F5D("1D871A
M7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM
M>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER
M92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I
M<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0IF;W)E86-H(&UY("1K97D@*'-O
M<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0[
M"B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G
M:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S970@
M/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@<WLD
M;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q
M*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I
M.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A
M=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H
M*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T10
M04XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ
M0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIM>2`E9FEL97,["B1F:6QE
M<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V
M86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB
M7V5X='T["FUY("5W<FET=&5N.PIF;W)E86-H("AS;W)T(&ME>7,@)69I;&5S
M*2!["FUY("@D;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY("1D:7(@*$!I;F,I
M('L*:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*
M)&9I;&4@/2`D7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>
M0V-=*2E<6B]I*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["FQA<W0[
M"GT*96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["FEF
M("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PHH
M)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*96QS:68@*"UF
M("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q
M*3L*;&%S=#L*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@
M;F]T("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N
M9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T<R@@:F]I;B`B(BP*
M<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F
M:6QE+`IQ<2@B+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI
M('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["F]P96X@1DE,
M12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*
M8FEN;6]D92A&24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X["F-L;W-E($9)3$4[
M"E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M
M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N
M86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H
M0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D[
M"GT*;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B
M1DE,12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@
M.2DI.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ
M6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP
M<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT
M*"1C;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@
M:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L
M(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D
M;W5T*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P
M96XH;7D@)&9H+"`B/"(L("1O=70I.PIB:6YM;V1E*"1F:"D["B1C='@M/F%D
M9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-A8VAE7VYA;64@/2`D8W1X+3YH
M97AD:6=E<W0["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T
M:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^
M<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M
M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@D4$%27TU!
M1TE#*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I[
M"FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M
M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E
M<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI:
M:7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/
M.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE
M("(D(3H@)$`B.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I
M.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B1Z:7`M/G)E861&<F]M
M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*07)C:&EV93HZ6FEP.CIS971#:'5N
M:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*
M)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D
M14Y6>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%
M3E9[4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@
M>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D
M;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI
M<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA
M;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O
M"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#
M;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?
M;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL
M92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S
M=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I
M*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@
M86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["GT@96QS92!["F]U
M=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M
M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I
M.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]
M"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID
M:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R
M(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R
M86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%
M3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%2
M1U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U
M:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X
M="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG
M*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P
M871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R
M;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I
M<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC
M=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A
M<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I
M<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E
M($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E
M8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@
M24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S
M<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T
M.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I
M<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T
M=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER
M92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A
M;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R
M97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U
M:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@
M<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F
M:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N
M*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D
M<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!4
M14U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2![
M"FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M
M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U
M:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I
M;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R
M.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R
M;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T52
M3D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@
M/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L
M:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP
M9&ER+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE
M(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N
M("1P<F]G;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M
M>2`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L
M("TU."P@,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O
M+V<["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U
M9CL*?0IE;'-E('L*;7D@)&1I9V5S="`](&5V86P*>PIR97%U:7)E($1I9V5S
M=#HZ4TA!.PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;BAM
M>2`D9F@L("(\(BP@)'!R;V=N86UE*3L*8FEN;6]D92@D9F@I.PHD8W1X+3YA
M9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C='@M/FAE>&1I9V5S=#L*?2!\
M?"`D;71I;64["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TD
M9&EG97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!
M3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"([
M"GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L
M(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-
M4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F
M:6QE('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D
M9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L
M;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@
M;7D@)&9H+"`G/B<L("1T96UP;F%M92!O<B!D:64@(F-A;B=T('=R:71E("1T
M96UP;F%M93H@)"$B.PIB:6YM;V1E("1F:#L*<')I;G0@)&9H("1C;VYT96YT
M<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN
M960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL
M:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E
M=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A
M;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@
M/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@
M86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*
M)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M
M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/
M1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^
M/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T
M=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X
M97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*
M?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]
M7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%
M35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D
M0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@
M+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5]
M(CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\
M/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#
M;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ
M9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'
M971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D
M*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<
M12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]
M("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM0
M05)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD
M14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@
M5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@
M)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.
M($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!
M3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM
M>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@
M("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#
M3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.
M?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG
M=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@
M/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@
M:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B([
M"GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E
M<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#
M;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@
M<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI
M8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@
M0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I
M.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O
M9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M
M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@
M*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI]
M.PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@
M*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ
M7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@!P97)L>'-I+F,`
M7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````"H%P``'!<```$````!`````0```.@"```/````
MC@0```P```!@$```#0```$`_```9````P'T!`!L````$````&@```,1]`0`<
M````!````/7^_V\L`0``!0```-0(```&````%`(```H```"L!```"P```!``
M```5``````````,```"X?@$``@```/`!```4````$0```!<```!P#@``$0``
M`(`-```2````\````!,````(````&`````````#[__]O`0``"/K__V\0````
M`````````````````````````````````````````````````````,A]`0``
M`````````&P0``!L$```;!```&P0``!L$```;!```&P0``!L$```;!```&P0
M``!L$```;!```&P0``!L$```;!```&P0``!L$```;!```&P0``!L$```;!``
M`&P0``!L$```;!```&P0``!L$```;!```&P0``!L$```;!```&P0``!L$```
M;!```&P0``!L$```;!```&P0``!L$```;!```&P0``!L$```;!```&P0``!L
M$```;!```&P0``!L$```;!```&P0``!L$```;!```&P0``!L$```;!```&P0
M``!L$```;!```&P0``!L$```;!```&P0``!L$```:!,`````````````0#\`
M````````````8!``````````````````````````````````````````````
M````````````@`$`_____TP_``!W/P```````%$_``!10```7#\``&-```!D
M/P```````&@_``!M/P````````5"``!'0T,Z("A!;'!I;F4@.2XS+C`I(#DN
M,RXP`$$R````865A8FD``2@````%-EI+``8'"`$)`0H"$@03`10!%0$7`Q@!
M&@(<`1X$(@%$`0`N<VAS=')T86(`+FEN=&5R<``N9VYU+FAA<V@`+F1Y;G-Y
M;0`N9'EN<W1R`"YR96PN9'EN`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI
M`"YR;V1A=&$`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD
M>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=``N05)-+F%T=')I8G5T
M97,`````````````````````````````````````````````````````````
M"P````$````"````%`$``!0!```8```````````````!`````````!,```#V
M__]O`@```"P!```L`0``Z`````,`````````!`````0````=````"P````(`
M```4`@``%`(``,`&```$`````P````0````0````)0````,````"````U`@`
M`-0(``"L!``````````````!`````````"T````)`````@```(`-``"`#0``
M\`````,`````````!`````@````V````"0```$(```!P#@``<`X``/`!```#
M````$`````0````(````/P````$````&````8!```&`0```,````````````
M```$`````````#H````!````!@```&P0``!L$```_`(`````````````!```
M``0```!%`````0````8```!H$P``:!,``-@K``````````````0`````````
M2P````$````&````0#\``$`_```,```````````````$`````````%$````!
M`````@```$P_``!,/P``2CT``````````````0````````!9`````0````(`
M``"8?```F'P```0```````````````0`````````8P````X````#````P'T!
M`,!]```$```````````````$````!````&\````/`````P```,1]`0#$?0``
M!```````````````!`````0```![````!@````,```#(?0$`R'T``/`````$
M``````````0````(````A`````$````#````N'X!`+A^``!(`0``````````
M```$````!````(D````!`````P````"``0``@```/```````````````!```
M``````"/````"`````,````\@`$`/(```#`0``````````````0`````````
ME`````$````P`````````#R````:```````````````!`````0```)T````#
M``!P``````````!6@```,P```````````````0`````````!`````P``````
>````````B8```*T```````````````$`````````
